<?php

namespace Layerdrops\Solox;

class Customizer
{
    public function __construct()
    {
        add_action("customize_register", [$this, 'solox_customizer']);
    }
    public function solox_customizer($wp_customize)
    {

        // add panel
        $wp_customize->add_panel(
            'solox_theme_opt',
            array(
                'title'      => esc_html__('Solox Options', 'solox-addon'),
                'description' => esc_html__('Solox Theme options panel', 'solox-addon'),
                'priority'   => 220,
                'capability' => 'edit_theme_options',
            )
        );

        // General Settings
        $wp_customize->add_section('solox_theme_general', array(
            'title' => __('General Settings', 'solox-addon'),
            'description' => esc_html__('Solox General Settings.', 'solox-addon'),
            'priority' => 10,
            'capability' => 'edit_theme_options',
            'panel'      => 'solox_theme_opt'
        ));

        $this->customize_type_radio(
            $wp_customize,
            esc_html__(' Enable Dark Mode?', 'solox-addon'),
            'solox_theme_general',
            'solox_dark_mode',
            'no',
            array(
                'yes' => esc_html__('Yes', 'solox-addon'),
                'no' => esc_html__('No', 'solox-addon'),
            )
        );

        $this->customize_type_radio(
            $wp_customize,
            esc_html__(' Enable Boxed Mode?', 'solox-addon'),
            'solox_theme_general',
            'solox_boxed_mode',
            'no',
            array(
                'yes' => esc_html__('Yes', 'solox-addon'),
                'no' => esc_html__('No', 'solox-addon'),
            )
        );

        $this->customize_type_radio(
            $wp_customize,
            esc_html__(' Enable Rtl Mode?', 'solox-addon'),
            'solox_theme_general',
            'solox_rtl_mode',
            'no',
            array(
                'yes' => esc_html__('Yes', 'solox-addon'),
                'no' => esc_html__('No', 'solox-addon'),
            )
        );

        $this->customize_type_radio(
            $wp_customize,
            esc_html__(' Enable Custom Cursor', 'solox-addon'),
            'solox_theme_general',
            'custom_cursor',
            'yes',
            array(
                'yes' => esc_html__('Yes', 'solox-addon'),
                'no' => esc_html__('No', 'solox-addon'),
            )
        );

        $this->customize_type_radio(
            $wp_customize,
            esc_html__(' Enable Back to top?', 'solox-addon'),
            'solox_theme_general',
            'scroll_to_top',
            'yes',
            array(
                'yes' => esc_html__('Yes', 'solox-addon'),
                'no' => esc_html__('No', 'solox-addon'),
            )
        );

        $this->customize_type_text(
            $wp_customize,
            esc_html__('Select Back to top text', 'solox-addon'),
            'solox_theme_general',
            'scroll_to_top_text',
            'back to top',
            function () {
                return (get_theme_mod('scroll_to_top', 'no') == 'yes' ? true : false);
            }
        );

        $this->customize_type_radio(
            $wp_customize,
            esc_html__(' Enable Preloader?', 'solox-addon'),
            'solox_theme_general',
            'preloader',
            'yes',
            array(
                'yes' => esc_html__('Yes', 'solox-addon'),
                'no' => esc_html__('No', 'solox-addon'),
            )
        );

        $this->customize_type_image(
            $wp_customize,
            esc_html__('Custom Preloader Image', 'solox-addon'),
            'solox_theme_general',
            'preloader_image',
            '',
            function () {
                return (get_theme_mod('preloader', 'no') == 'yes' ? true : false);
            }
        );

        $this->customize_type_image(
            $wp_customize,
            esc_html__('Page Header Image', 'solox-addon'),
            'solox_theme_general',
            'page_header_bg_image'
        );

        $this->customize_type_image(
            $wp_customize,
            esc_html__('Page Header Shape One', 'solox-addon'),
            'solox_theme_general',
            'page_header_shape_one'
        );

        $this->customize_type_image(
            $wp_customize,
            esc_html__('Page Header Shape Two', 'solox-addon'),
            'solox_theme_general',
            'page_header_shape_two'
        );

        $this->customize_type_image(
            $wp_customize,
            esc_html__('Page Header Shape Three', 'solox-addon'),
            'solox_theme_general',
            'page_header_shape_three'
        );

        // Color Settings
        $wp_customize->add_section('solox_theme_color', array(
            'title' => __('Color Settings', 'solox-addon'),
            'description' => esc_html__('Solox Color Settings.', 'solox-addon'),
            'priority' => 10,
            'capability' => 'edit_theme_options',
            'panel'      => 'solox_theme_opt'
        ));

        solox_source_color_meta('set_customizer', $wp_customize, $this);

        // Blog Layout
        $wp_customize->add_section('solox_blog_layout_settings', array(
            'title' => __('Blog Layout', 'solox-addon'),
            'description' => esc_html__('Solox Blog Layout', 'solox-addon'),
            'priority' => 20,
            'capability' => 'edit_theme_options',
            'panel'      => 'solox_theme_opt'
        ));

        $this->customize_type_select(
            $wp_customize,
            'Select Sidebar position',
            'solox_blog_layout_settings',
            'solox_blog_layout',
            'right-align',
            array(
                'left-align' => esc_html__('Left Align', 'solox-addon'),
                'right-align' => esc_html__('Right Align', 'solox-addon'),
                'full-width' => esc_html__('Full Width', 'solox-addon'),
            )
        );

        // Shop Layout
        $wp_customize->add_section('solox_shop_layout_settings', array(
            'title' => __('Shop Layout', 'solox-addon'),
            'description' => esc_html__('solox Shop Layout', 'solox-addon'),
            'priority' => 20,
            'capability' => 'edit_theme_options',
            'panel'      => 'solox_theme_opt'
        ));


        $this->customize_type_select(
            $wp_customize,
            'Select Shop Column',
            'solox_shop_layout_settings',
            'solox_shop_column',
            '3',
            array(
                '2' => esc_html__('2 Column', 'solox-addon'),
                '3' => esc_html__('3 Column', 'solox-addon'),
                '4' => esc_html__('4 Column', 'solox-addon'),
            )
        );

        $this->customize_type_select(
            $wp_customize,
            'Select Shop Sidebar position',
            'solox_shop_layout_settings',
            'solox_shop_layout',
            'left-align',
            array(
                'left-align' => esc_html__('Left Align', 'solox-addon'),
                'right-align' => esc_html__('Right Align', 'solox-addon'),
                'full-width' => esc_html__('Full Width', 'solox-addon'),
            )
        );

        $this->customize_type_text(
            $wp_customize,
            esc_html__('Shop Product Per page', 'solox-addon'),
            'solox_shop_layout_settings',
            'product_per_page',
            esc_html(12)
        );

        // Header options
        $wp_customize->add_section('solox_theme_header', array(
            'title' => __('Header Settings', 'solox-addon'),
            'description' => esc_html__('Solox Header Settings', 'solox-addon'),
            'priority' => 20,
            'capability' => 'edit_theme_options',
            'panel'      => 'solox_theme_opt'
        ));

        $this->customize_type_text(
            $wp_customize,
            esc_html__('Add Logo size in px', 'solox-addon'),
            'solox_theme_header',
            'header_logo_width',
            esc_html(198)
        );

        $this->customize_type_radio(
            $wp_customize,
            esc_html__('Enable Sticky Header?', 'solox-addon'),
            'solox_theme_header',
            'header_sticky_menu',
            'yes',
            array(
                'yes' => esc_html__('Yes', 'solox-addon'),
                'no' => esc_html__('No', 'solox-addon'),
            )
        );

        $this->customize_type_radio(
            $wp_customize,
            esc_html__(' Enable Breadcrumb?', 'solox-addon'),
            'solox_theme_header',
            'breadcrumb_opt',
            'yes',
            array(
                'yes' => esc_html__('Yes', 'solox-addon'),
                'no' => esc_html__('No', 'solox-addon'),
            )
        );

        $this->customize_type_radio(
            $wp_customize,
            esc_html__('Enable Custom Header?', 'solox-addon'),
            'solox_theme_header',
            'header_custom',
            'no',
            array(
                'yes' => esc_html__('Yes', 'solox-addon'),
                'no' => esc_html__('No', 'solox-addon'),
            )
        );

        $this->customize_type_select(
            $wp_customize,
            esc_html__('Select Header Type', 'solox-addon'),
            'solox_theme_header',
            'header_custom_post',
            '',
            solox_post_query('header'),
            function () {
                return (get_theme_mod('header_custom', 'no') == 'yes' ? true : false);
            }
        );

        //  Mobile Menu
        $wp_customize->add_section('solox_theme_mobile_menu', array(
            'title' => esc_html__('Mobile Menu Settings', 'solox-addon'),
            'description' => esc_html__('Solox Header Settings', 'solox-addon'),
            'priority' => 20,
            'capability' => 'edit_theme_options',
            'panel'      => 'solox_theme_opt'
        ));

        $this->customize_type_text(
            $wp_customize,
            esc_html__('Mobile Menu Email', 'solox-addon'),
            'solox_theme_mobile_menu',
            'solox_mobile_menu_email',
            esc_html__('needhelp@solox.com', 'solox-addon')
        );

        $this->customize_type_text(
            $wp_customize,
            esc_html__('Mobile Menu Phone', 'solox-addon'),
            'solox_theme_mobile_menu',
            'solox_mobile_menu_phone',
            esc_html__('666 888 0000', 'solox-addon')
        );

        $this->customize_type_text(
            $wp_customize,
            esc_html__('Facebook url', 'solox-addon'),
            'solox_theme_mobile_menu',
            'facebook_url',
            esc_html('#')
        );

        $this->customize_type_text(
            $wp_customize,
            esc_html__('Twitter url', 'solox-addon'),
            'solox_theme_mobile_menu',
            'twitter_url',
            esc_html('#')
        );

        $this->customize_type_text(
            $wp_customize,
            esc_html__('Linkedin url', 'solox-addon'),
            'solox_theme_mobile_menu',
            'linkedin_url',
            esc_html('#')
        );

        $this->customize_type_text(
            $wp_customize,
            esc_html__('Pinterest url', 'solox-addon'),
            'solox_theme_mobile_menu',
            'pinterest_url',
            esc_html('#')
        );

        $this->customize_type_text(
            $wp_customize,
            esc_html__('Youtube url', 'solox-addon'),
            'solox_theme_mobile_menu',
            'youtube_url',
        );


        $this->customize_type_text(
            $wp_customize,
            esc_html__('dribbble url', 'solox-addon'),
            'solox_theme_mobile_menu',
            'dribble_url',
        );

        $this->customize_type_text(
            $wp_customize,
            esc_html__('Instagram url', 'solox-addon'),
            'solox_theme_mobile_menu',
            'instagram_url',
        );

        $this->customize_type_text(
            $wp_customize,
            esc_html__('Reddit url', 'solox-addon'),
            'solox_theme_mobile_menu',
            'reddit_url',
        );

        // Footer options
        $wp_customize->add_section('solox_theme_footer', array(
            'title' => esc_html__('Footer Settings', 'solox-addon'),
            'description' => esc_html__('Solox Footer Settings.', 'solox-addon'),
            'priority' => 20,
            'capability' => 'edit_theme_options',
            'panel'      => 'solox_theme_opt'
        ));

        $this->customize_type_text(
            $wp_customize,
            esc_html__('Footer Text', 'solox-addon'),
            'solox_theme_footer',
            'footer_copytext',
            esc_html__('&copy; All right reserved', 'solox'),
            function () {
                return (get_theme_mod('footer_custom', 'no') == 'yes' ? false : true);
            }
        );

        $this->customize_type_radio(
            $wp_customize,
            esc_html__('Enable Custom Footer ?', 'solox-addon'),
            'solox_theme_footer',
            'footer_custom',
            'no',
            array(
                'yes' => esc_html__('Yes', 'solox-addon'),
                'no' => esc_html__('No', 'solox-addon'),
            )
        );

        $this->customize_type_select(
            $wp_customize,
            esc_html__('Select Footer Type', 'solox-addon'),
            'solox_theme_footer',
            'footer_custom_post',
            '',
            solox_post_query('footer'),
            function () {
                return (get_theme_mod('footer_custom', 'no') == 'yes' ? true : false);
            }
        );

        // register
        $wp_customize->add_section('solox_login_settings', array(
            'title' => __('Login/Register Settings', 'solox-addon'),
            'description' => esc_html__('Login/Register Settings', 'solox-addon'),
            'priority' => 20,
            'capability' => 'edit_theme_options',
            'panel'      => 'solox_theme_opt'
        ));

        $this->customize_type_text(
            $wp_customize,
            esc_html__('Redirect url After Login', 'solox-addon'),
            'solox_login_settings',
            'login_redirect_url',
        );

        $this->customize_type_text(
            $wp_customize,
            esc_html__('Redirect url After Registration', 'solox-addon'),
            'solox_login_settings',
            'registration_redirect_url',
        );

        $this->customize_type_text(
            $wp_customize,
            esc_html__('Redirect url After Log Out', 'solox-addon'),
            'solox_login_settings',
            'logout_redirect_url',
        );

        // error page
        $wp_customize->add_section('solox_error_page_settings', array(
            'title' => __('404 Settings', 'solox-addon'),
            'description' => esc_html__('Change 404 Text', 'solox-addon'),
            'priority' => 20,
            'capability' => 'edit_theme_options',
            'panel'      => 'solox_theme_opt'
        ));

        $this->customize_type_radio(
            $wp_customize,
            esc_html__('Enable Custom 404 ?', 'solox-addon'),
            'solox_error_page_settings',
            'error_custom',
            'no',
            array(
                'yes' => esc_html__('Yes', 'solox-addon'),
                'no' => esc_html__('No', 'solox-addon'),
            )
        );

        $this->customize_type_select(
            $wp_customize,
            esc_html__('Select 404 Page', 'solox-addon'),
            'solox_error_page_settings',
            'error_custom_post',
            '',
            solox_post_query('page'),
            function () {
                return (get_theme_mod('error_custom', 'no') == 'yes' ? true : false);
            }
        );

        $this->customize_type_image(
            $wp_customize,
            esc_html__('404 Page Title Image', 'solox-addon'),
            'solox_error_page_settings',
            '404_page_title_image'
        );
    }

    //type text
    public function customize_type_text($wp_customize, $label, $section_id, $name,  $default = "", $callback = null)
    {
        // add settings
        $wp_customize->add_setting($name, array(
            'default'  => $default,
            'type'     => 'theme_mod'
        ));

        $wp_customize->add_control(new \WP_Customize_Control(
            $wp_customize,
            $name,
            array(
                "label" => $label,
                "section" => $section_id,
                "settings" => $name,
                "type" => "text",
                "active_callback" => $callback,
            )
        ));
    }


    //type color
    //type color
    public function customize_type_color($wp_customize, $section_id, $name,  $default = false)
    {
        $prefix_name = str_replace("-", "_", $name);
        // add settings
        $wp_customize->add_setting($prefix_name, array(
            'default'  => sanitize_hex_color($default),
            'type'     => 'theme_mod'
        ));

        // Add control
        $wp_customize->add_control(new \WP_Customize_Color_Control($wp_customize, $prefix_name, array(
            'label'    => ucwords(str_replace("-", " ", $name)),
            'section'  => $section_id,
            'setting' => $prefix_name,
            'priority' => 1
        )));
    }

    // type checkbox
    public function customize_type_checkbox($wp_customize, $label, $section_id, $name,  $default, $callback = null)
    {
        $wp_customize->add_setting($name, array(
            "default" => $default,
            "transport" => "refresh",

        ));

        $wp_customize->add_control(new \WP_Customize_Control(
            $wp_customize,
            $name,
            array(
                "label" => $label,
                "section" => $section_id,
                "settings" => $name,
                "type" => "checkbox",
                "active_callback" => $callback,
            )
        ));
    }

    // type Image
    public function customize_type_image($wp_customize, $label, $section_id, $name,  $default = '', $callback = null)
    {
        $wp_customize->add_setting($name, array(
            "default" => $default,
            "transport" => "refresh",

        ));

        $wp_customize->add_control(new \WP_Customize_Upload_Control($wp_customize, $name, array(
            'label'    => $label,
            'section'  => $section_id,
            'setting' => $name,
            'priority' => 20,
            "active_callback" => $callback,
        )));
    }

    public function customize_type_select($wp_customize, $label, $section_id, $name,  $default, $select_value,  $callback = null)
    {
        $wp_customize->add_setting($name, array(
            'default'     => $default,
            "transport" => "refresh",

        ));

        $wp_customize->add_control(new \WP_Customize_Control(
            $wp_customize,
            $name,
            array(
                "label" => $label,
                "section" => $section_id,
                "settings" => $name,
                "type" => "select",
                'choices'     => $select_value,
                "active_callback" => $callback,
            )
        ));
    }

    public function customize_type_radio($wp_customize, $label, $section_id, $name,  $default, $radio_value, $callback = null)
    {
        $wp_customize->add_setting($name, array(
            'default'     => $default,
            "transport" => "refresh",

        ));

        $wp_customize->add_control(new \WP_Customize_Control(
            $wp_customize,
            $name,
            array(
                "label" => $label,
                "section" => $section_id,
                "settings" => $name,
                "type" => "radio",
                'choices'     => $radio_value,
                "active_callback" => $callback,
            )
        ));
    }
}
