<?php

namespace Layerdrops\Solox\Widgets;


class About extends \Elementor\Widget_Base
{
	public function get_name()
	{
		return 'solox-about';
	}

	public function get_title()
	{
		return __('About', 'solox-addon');
	}

	public function get_icon()
	{
		return 'eicon-cogs';
	}

	public function get_categories()
	{
		return ['solox-category'];
	}

	protected function register_controls()
	{
		$this->start_controls_section(
			'layout_section',
			[
				'label' => __('Layout', 'solox-addon'),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'layout_type',
			[
				'label' => __('Select Layout', 'solox-addon'),
				'type' => \Elementor\Controls_Manager::SELECT2,
				'default' => 'layout_one',
				'options' => [
					'layout_one' => __('Layout One', 'solox-addon'),
					'layout_two' => __('Layout Two', 'solox-addon'),
					'layout_three' => __('Layout Three', 'solox-addon'),
					'layout_four' => __('Layout Four', 'solox-addon'),
				]
			]
		);

		$this->end_controls_section();

		include solox_get_elementor_option('about-one-option.php');
		include solox_get_elementor_option('about-two-option.php');
		include solox_get_elementor_option('about-three-option.php');
		include solox_get_elementor_option('about-four-option.php');

		//General style
		$this->start_controls_section(
			'general_style',
			[
				'label' => esc_html__('Content Style', 'solox-addon'),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		solox_elementor_general_style_options($this, 'Section Title', '{{WRAPPER}} .sec-title__title,{{WRAPPER}} .about-three__con-middle__title', ['layout_one', 'layout_two', 'layout_three', 'layout_four']);
		solox_elementor_general_style_options($this, 'Section Sub Title', '{{WRAPPER}} .sec-title__tagline,{{WRAPPER}} .about-three__con-middle__text-one', ['layout_one', 'layout_two', 'layout_three', 'layout_four']);

		solox_elementor_general_style_options($this, 'Summary Text', '{{WRAPPER}} .why-choose-two__text,{{WRAPPER}} .about-one__content__text-two,{{WRAPPER}} .about-two__content__text,{{WRAPPER}} .about-three__con-middle__text-two', ['layout_one', 'layout_two', 'layout_three', 'layout_four']);
		solox_elementor_general_style_options($this, 'Highlighted Text', '{{WRAPPER}} .why-choose-two__highlight,{{WRAPPER}} .about-one__content__text-one', ['layout_two']);

		solox_elementor_general_style_options($this, 'Progress Title', '{{WRAPPER}} .why-choose-two__text', ['layout_one']);
		solox_elementor_general_style_options($this, 'Progress Number', '{{WRAPPER}} .why-choose-two__progress__number', ['layout_one']);

		solox_elementor_general_style_options($this, 'Content Title', '{{WRAPPER}} .about-one__content__list li,{{WRAPPER}} .about-two__content__list li,{{WRAPPER}} .about-three__con-right__title', ['layout_two', 'layout_three', 'layout_four']);
		solox_elementor_general_style_options($this, 'Author Content', '{{WRAPPER}} .about-one__content__author__meta,{{WRAPPER}} .about-two__content__author__meta', ['layout_two', 'layout_three']);

		solox_elementor_general_style_options($this, 'Check List Title', '{{WRAPPER}} .about-three__list li', ['layout_four']);

		solox_elementor_general_style_options($this, 'Info Title', '{{WRAPPER}} .about-two__info__title', ['layout_three']);
		solox_elementor_general_style_options($this, 'INfo Text', '{{WRAPPER}} .about-two__info__text', ['layout_three']);
		solox_elementor_general_style_options($this, 'Date', '{{WRAPPER}} .about-two__info__list__item', ['layout_three']);
		solox_elementor_general_style_options($this, 'Time', '{{WRAPPER}} .about-two__info__list__time', ['layout_three']);
		$this->end_controls_section();

		//Button style
		$this->start_controls_section(
			'button_style',
			[
				'label' => esc_html__('Button Style', 'solox-addon'),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		solox_elementor_button_style_options($this, 'Button', '{{WRAPPER}} .solox-btn::before', '{{WRAPPER}} .solox-btn::after', ['layout_one', 'layout_two', 'layout_four']);

		$this->end_controls_section();
	}

	protected function render()
	{
		$settings = $this->get_settings_for_display();
		include solox_get_template('about-one.php');
		include solox_get_template('about-two.php');
		include solox_get_template('about-three.php');
		include solox_get_template('about-four.php');
	}
}
