<?php

namespace Layerdrops\Solox\Widgets;


class CallToAction extends \Elementor\Widget_Base
{
    public function get_name()
    {
        return 'solox-call-to-action';
    }

    public function get_title()
    {
        return __('Call To Action', 'solox-addon');
    }

    public function get_icon()
    {
        return 'eicon-cogs';
    }

    public function get_categories()
    {
        return ['solox-category'];
    }

    protected function register_controls()
    {
        $this->start_controls_section(
            'layout_section',
            [
                'label' => __('Layout', 'solox-addon'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'layout_type',
            [
                'label' => __('Select Layout', 'solox-addon'),
                'type' => \Elementor\Controls_Manager::SELECT2,
                'default' => 'layout_one',
                'options' => [
                    'layout_one' => __('Layout One', 'solox-addon'),
                    'layout_two' => __('Layout Two', 'solox-addon'),
                    // 'layout_three' => __('Layout Three', 'solox-addon'),
                ]
            ]
        );
        $this->end_controls_section();

        include solox_get_elementor_option('call-to-action-one-option.php');
        include solox_get_elementor_option('call-to-action-two-option.php');
        // include solox_get_elementor_option('call-to-action-three-option.php');

        //General style
        $this->start_controls_section(
            'general_style',
            [
                'label' => esc_html__('Content Style', 'solox-addon'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        solox_elementor_general_style_options($this, 'Title', '{{WRAPPER}} .cta-two__title,{{WRAPPER}} .cta-one__title', ['layout_one', 'layout_two']);
        solox_elementor_general_style_options($this, 'Subtitle', '{{WRAPPER}} .cta-two__sub-title', ['layout_one']);
        $this->end_controls_section();

        //button style
        $this->start_controls_section(
            'button_style',
            [
                'label' => esc_html__('Button Style', 'solox-addon'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
                'condition' => [
                    'layout_type' => ['layout_one', 'layout_two']
                ]
            ]
        );

        solox_elementor_button_style_options($this, 'Button', '{{WRAPPER}} .solox-btn::before,{{WRAPPER}} .cta-one__link::before', '{{WRAPPER}} .solox-btn::after,{{WRAPPER}} .cta-one__link::after', ['layout_one', 'layout_two']);

        $this->end_controls_section();
    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        include solox_get_template('call-to-action-one.php');
        include solox_get_template('call-to-action-two.php');
        // include solox_get_template('call-to-action-three.php');
    }
}
