<?php

namespace Layerdrops\Solox\Widgets;


class ContactForm extends \Elementor\Widget_Base
{
    public function get_name()
    {
        return 'solox-contact-form';
    }

    public function get_title()
    {
        return __('Contact Form', 'solox-addon');
    }

    public function get_icon()
    {
        return 'eicon-cogs';
    }

    public function get_categories()
    {
        return ['solox-category'];
    }

    protected function register_controls()
    {
        $this->start_controls_section(
            'layout_section',
            [
                'label' => __('Layout', 'solox-addon'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'layout_type',
            [
                'label' => __('Select Layout', 'solox-addon'),
                'type' => \Elementor\Controls_Manager::SELECT2,
                'default' => 'layout_one',
                'options' => [
                    'layout_one' => __('Layout One', 'solox-addon'),
                    'layout_two' => __('Layout Two', 'solox-addon'),
                    'layout_three' => __('Layout Three', 'solox-addon'),
                    'layout_four' => __('Layout Four', 'solox-addon'),
                    // 'layout_five' => __('Layout Five', 'solox-addon'),
                ]
            ]
        );

        $this->end_controls_section();

        include solox_get_elementor_option('contact-form-one-option.php');
        include solox_get_elementor_option('contact-form-two-option.php');
        include solox_get_elementor_option('contact-form-three-option.php');
        include solox_get_elementor_option('contact-form-four-option.php');
        // include solox_get_elementor_option('contact-form-five-option.php');

        //General style
        $this->start_controls_section(
            'general_style',
            [
                'label' => esc_html__('Content Style', 'solox-addon'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        solox_elementor_general_style_options($this, 'Section Title', '{{WRAPPER}} .sec-title__title', ['layout_one', 'layout_two', 'layout_three', 'layout_four']);
        solox_elementor_general_style_options($this, 'Section Sub Title', '{{WRAPPER}} .sec-title__tagline', ['layout_one', 'layout_two', 'layout_three', 'layout_four']);
        solox_elementor_general_style_options($this, 'Section Summary', '{{WRAPPER}} .contact-one__text', ['layout_one', 'layout_three']);

        solox_elementor_general_style_options($this, 'Form  Title', '{{WRAPPER}} .contact-one__form__top .sec-title__title', ['layout_one', 'layout_three']);
        solox_elementor_general_style_options($this, 'Form  Subtitle', '{{WRAPPER}} .contact-one__form__top .sec-title__tagline', ['layout_one', 'layout_three']);

        solox_elementor_general_style_options($this, 'Info  Title', '{{WRAPPER}} .contact-one__info__text', ['layout_one', 'layout_three']);
        solox_elementor_general_style_options($this, 'Info  Subtitle', '{{WRAPPER}} .contact-one__info__title a', ['layout_one', 'layout_three']);


        $this->end_controls_section();

        //button style
        $this->start_controls_section(
            'button_style',
            [
                'label' => esc_html__('Button Style', 'solox-addon'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        solox_elementor_button_style_options($this, 'Button', '{{WRAPPER}} .solox-btn,{{WRAPPER}} .solox-btn::before', '{{WRAPPER}} .solox-btn:hover,{{WRAPPER}} .solox-btn::after', ['layout_one', 'layout_two', 'layout_three', 'layout_four']);

        $this->end_controls_section();

        //form Option style
        $this->start_controls_section(
            'form_style',
            [
                'label' => esc_html__('Form Field Style', 'solox-addon'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        solox_elementor_form_style_options($this, 'Input Text', '{{WRAPPER}} input[type="text"]', ['layout_one', 'layout_two', 'layout_three', 'layout_four', 'layout_five']);
        solox_elementor_form_style_options($this, 'Input Email', '{{WRAPPER}} input[type="email"]', ['layout_one', 'layout_two', 'layout_three', 'layout_four', 'layout_five']);
        solox_elementor_form_style_options($this, 'Textarea', '{{WRAPPER}}  textarea', ['layout_one', 'layout_two', 'layout_three', 'layout_four', 'layout_five']);
        solox_elementor_form_style_options($this, 'Input Url', '{{WRAPPER}} input[type="url"]', ['layout_one', 'layout_two', 'layout_three', 'layout_four', 'layout_five']);
        solox_elementor_form_style_options($this, 'Input Number', '{{WRAPPER}} input[type="number"]', ['layout_one', 'layout_two', 'layout_three', 'layout_four', 'layout_five']);
        solox_elementor_form_style_options($this, 'Input Tel', '{{WRAPPER}} input[type="tel"]', ['layout_one', 'layout_two', 'layout_three', 'layout_four', 'layout_five']);

        $this->end_controls_section();
    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        include solox_get_template('contact-form-one.php');
        include solox_get_template('contact-form-two.php');
        include solox_get_template('contact-form-three.php');
        include solox_get_template('contact-form-four.php');
        // include solox_get_template('contact-form-five.php');
    }
}
