<?php

namespace Layerdrops\Solox\Widgets;


class Login extends \Elementor\Widget_Base
{
    public function get_name()
    {
        return 'solox-login';
    }

    public function get_title()
    {
        return __('Login', 'solox-addon');
    }

    public function get_icon()
    {
        return 'eicon-cogs';
    }

    public function get_categories()
    {
        return ['solox-category'];
    }

    protected function register_controls()
    {
        $this->start_controls_section(
            'layout_section',
            [
                'label' => __('Layout', 'solox-addon'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'layout_type',
            [
                'label' => __('Select Layout', 'solox-addon'),
                'type' => \Elementor\Controls_Manager::SELECT2,
                'default' => 'layout_one',
                'options' => [
                    'layout_one' => __('Layout One', 'solox-addon'),
                ]
            ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
            'content_section',
            [
                'label' => __('Content', 'solox-addon'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'layout_type' => 'layout_one'
                ]
            ]
        );

        $this->add_control(
            'title',
            [
                'label' => __('Title', 'solox-addon'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('Login ', 'solox-addon'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'user_name_placeholder',
            [
                'label' => __('Placeholder for username', 'solox-addon'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('Username or Email Address* ', 'solox-addon'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'password_placeholder',
            [
                'label' => __('Placeholder for Password', 'solox-addon'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('Password* ', 'solox-addon'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'remember_me_text',
            [
                'label' => __('Remember Me Text', 'solox-addon'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('Remember Me?', 'solox-addon'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'login_btn_text',
            [
                'label' => __('Login Button Text', 'solox-addon'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('Login', 'solox-addon'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'forget_text',
            [
                'label' => __('Forgot Password Text', 'solox-addon'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __('Forgot your Password?', 'solox-addon'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'forget_url',
            [
                'label' => __('Forgot Password Url', 'solox-addon'),
                'type' => \Elementor\Controls_Manager::URL,
                'placeholder' => __('#', 'solox-addon'),
                'show_external' => false,
                'default' => [
                    'url' => '#',
                    'is_external' => false,
                    'nofollow' => true,
                ],
                'show_label' => false,
            ]
        );

        $this->end_controls_section();

        //style
        $this->start_controls_section(
            'style_options',
            [
                'label' => esc_html__('Style Options', 'solox-addon'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        solox_elementor_general_style_options($this, 'Title', '{{WRAPPER}} .login-page__wrap__title', ['layout_one']);
        solox_elementor_general_style_options($this, 'Remember Me', '{{WRAPPER}} .login-page__form .checked-box label', ['layout_one']);
        solox_elementor_general_style_options($this, 'Forgot Password', '{{WRAPPER}} .login-page__form-forgot-password a', ['layout_one']);
        $this->end_controls_section();

        //button style
        $this->start_controls_section(
            'button_style',
            [
                'label' => esc_html__('Button Style', 'solox-addon'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        solox_elementor_button_style_options($this, 'Button', '{{WRAPPER}} .solox-btn', '{{WRAPPER}} .solox-btn:hover', ['layout_one']);

        $this->end_controls_section();
    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        include solox_get_template('login-one.php');
    }
}
