<?php

namespace Layerdrops\Solox\Widgets;


class MainSlider extends \Elementor\Widget_Base
{
    public function get_name()
    {
        return 'solox-main-slider';
    }

    public function get_title()
    {
        return __('Main Slider', 'solox-addon');
    }

    public function get_icon()
    {
        return 'eicon-cogs';
    }

    public function get_categories()
    {
        return ['solox-category'];
    }

    protected function register_controls()
    {
        $this->start_controls_section(
            'layout_section',
            [
                'label' => __('Layout', 'solox-addon'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'layout_type',
            [
                'label' => __('Select Layout', 'solox-addon'),
                'type' => \Elementor\Controls_Manager::SELECT2,
                'default' => 'layout_one',
                'options' => [
                    'layout_one' => __('Layout One', 'solox-addon'),
                    'layout_two' => __('Layout Two', 'solox-addon'),
                    'layout_three' => __('Layout Three', 'solox-addon'),
                ]
            ]
        );


        $this->end_controls_section();

        include solox_get_elementor_option('main-slider-one-option.php');
        include solox_get_elementor_option('main-slider-two-option.php');
        include solox_get_elementor_option('main-slider-three-option.php');

        //General style
        $this->start_controls_section(
            'general_style',
            [
                'label' => esc_html__('Content Style', 'solox-addon'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        solox_elementor_general_style_options($this, 'Title', '{{WRAPPER}} .main-slider-one__title, {{WRAPPER}} .main-slider-two__title, {{WRAPPER}} .main-slider-three__title', ['layout_one', 'layout_two', 'layout_three']);
        solox_elementor_general_style_options($this, 'Sub Title', '{{WRAPPER}} .main-slider-one__sub-title, {{WRAPPER}} .main-slider-two__sub-title, {{WRAPPER}} .main-slider-three__sub-title', ['layout_one', 'layout_two', 'layout_three']);
        solox_elementor_general_style_options($this, 'Video Text', '{{WRAPPER}} .curved-circle--item span', ['layout_three']);

        $this->end_controls_section();

        //button style
        $this->start_controls_section(
            'button_style',
            [
                'label' => esc_html__('Button Style', 'solox-addon'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        solox_elementor_button_style_options($this, 'Button', '{{WRAPPER}} .solox-btn::before', '{{WRAPPER}} .solox-btn::after', ['layout_one', 'layout_two', 'layout_three']);

        $this->end_controls_section();

        solox_get_elementor_carousel_options($this, ['layout_one', 'layout_two', 'layout_three']);
    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        include solox_get_template('main-slider-one.php');
        include solox_get_template('main-slider-two.php');
        include solox_get_template('main-slider-three.php');
    }
}
