<?php

namespace Layerdrops\Solox\Widgets;


class Service extends \Elementor\Widget_Base
{
    public function get_name()
    {
        return 'solox-service';
    }

    public function get_title()
    {
        return __('Service', 'solox-addon');
    }

    public function get_icon()
    {
        return 'eicon-cogs';
    }

    public function get_categories()
    {
        return ['solox-category'];
    }

    protected function register_controls()
    {
        $this->start_controls_section(
            'layout_section',
            [
                'label' => __('Layout', 'solox-addon'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'layout_type',
            [
                'label' => __('Select Layout', 'solox-addon'),
                'type' => \Elementor\Controls_Manager::SELECT2,
                'default' => 'layout_one',
                'options' => [
                    'layout_one' => __('Layout One', 'solox-addon'),
                    'layout_two' => __('Layout Two', 'solox-addon'),
                    'layout_three' => __('Layout Three', 'solox-addon'),
                    'layout_four' => __('Layout Four', 'solox-addon'),
                    'layout_five' => __('Layout Five', 'solox-addon'),
                ]
            ]
        );


        $this->end_controls_section();

        include solox_get_elementor_option('service-one-option.php');
        include solox_get_elementor_option('service-two-option.php');
        include solox_get_elementor_option('service-three-option.php');
        include solox_get_elementor_option('service-four-option.php');

        //General style
        $this->start_controls_section(
            'general_style',
            [
                'label' => esc_html__('Content Style', 'solox-addon'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );


        solox_elementor_general_style_options($this, 'Section Title', '{{WRAPPER}} .sec-title__title', ['layout_two', 'layout_four']);
        solox_elementor_general_style_options($this, 'Section Sub Title', '{{WRAPPER}} .sec-title__tagline', ['layout_two', 'layout_four']);

        solox_elementor_general_style_options($this, 'Service Title', '{{WRAPPER}} .service-card-two__title a,{{WRAPPER}} .service-one__item__title a', ['layout_one', 'layout_two', 'layout_three', 'layout_four']);
        solox_elementor_general_style_options($this, 'Service Sub Title', '{{WRAPPER}} .service-card-two__text', ['layout_one', 'layout_three', 'layout_four']);

        solox_elementor_general_style_options($this, 'Bottom Text', '{{WRAPPER}} .service-one__info__text', ['layout_two']);

        $this->end_controls_section();

        //button style
        $this->start_controls_section(
            'button_style',
            [
                'label' => esc_html__('Button Style', 'solox-addon'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        solox_elementor_button_style_options($this, 'Button', '{{WRAPPER}} .service-card-two__link,{{WRAPPER}} .solox-btn--base::before', '{{WRAPPER}} .service-card-two__link:hover,{{WRAPPER}} .solox-btn--base:hover', ['layout_one', 'layout_two', 'layout_three', 'layout_four']);

        $this->end_controls_section();

        solox_get_elementor_carousel_options($this, ['layout_one', 'layout_four']);
        solox_elementor_column_count_options($this, ['layout_two']);
    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        include solox_get_template('service-one.php');
        include solox_get_template('service-two.php');
        include solox_get_template('service-three.php');
        include solox_get_template('service-four.php');
        include solox_get_template('service-five.php');
    }
}
