<?php

namespace Layerdrops\Solox\Widgets;


class Team extends \Elementor\Widget_Base
{
    public function get_name()
    {
        return 'solox-team';
    }

    public function get_title()
    {
        return __('Team', 'solox-addon');
    }

    public function get_icon()
    {
        return 'eicon-cogs';
    }

    public function get_categories()
    {
        return ['solox-category'];
    }

    protected function register_controls()
    {
        $this->start_controls_section(
            'layout_section',
            [
                'label' => __('Layout', 'solox-addon'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'layout_type',
            [
                'label' => __('Select Layout', 'solox-addon'),
                'type' => \Elementor\Controls_Manager::SELECT2,
                'default' => 'layout_one',
                'options' => [
                    'layout_one' => __('Layout One', 'solox-addon'),
                    'layout_two' => __('Layout Two', 'solox-addon'),
                    'layout_three' => __('Layout Three', 'solox-addon'),
                    'layout_four' => __('Layout Four', 'solox-addon'),
                ]
            ]
        );

        $this->end_controls_section();

        include solox_get_elementor_option('team-one-option.php');
        include solox_get_elementor_option('team-three-option.php');
        include solox_get_elementor_option('team-four-option.php');

        //General style
        $this->start_controls_section(
            'general_style',
            [
                'label' => esc_html__('Content Style', 'solox-addon'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        solox_elementor_general_style_options($this, 'Section Title', '{{WRAPPER}} .section-title__title', ['layout_five']);
        solox_elementor_general_style_options($this, 'Section Sub Title', '{{WRAPPER}} .section-title__tagline', ['layout_five']);

        solox_elementor_general_style_options($this, 'Name', '{{WRAPPER}} .team-card__title a', ['layout_one', 'layout_two']);
        solox_elementor_general_style_options($this, 'Designation', '{{WRAPPER}} .team-card__designation', ['layout_one', 'layout_two']);


        solox_elementor_general_style_options($this, 'Title', '{{WRAPPER}} .team-details__title', ['layout_three']);
        solox_elementor_general_style_options($this, 'Summary', '{{WRAPPER}} .team-details__text', ['layout_three']);
        solox_elementor_general_style_options($this, 'Features Title', '{{WRAPPER}} .team-details__highlight', ['layout_three']);
        solox_elementor_general_style_options($this, 'Features List', '{{WRAPPER}} .team-details__list li', ['layout_three']);
        solox_elementor_general_style_options($this, 'Progressbar Title', '{{WRAPPER}} .team-skills-one__progress__title', ['layout_three']);
        solox_elementor_general_style_options($this, 'Progressbar Count', '{{WRAPPER}} .team-skills-one__progress__number', ['layout_three']);
        solox_elementor_general_style_options($this, 'Image Title', '{{WRAPPER}} .team-details__icon__text', ['layout_three']);

        $this->end_controls_section();

        solox_elementor_column_count_options($this, ['layout_one']);

        solox_get_elementor_carousel_options($this, ['layout_two', 'layout_four']);
    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        include solox_get_template('team-one.php');
        include solox_get_template('team-two.php');
        include solox_get_template('team-three.php');
        include solox_get_template('team-four.php');
    }
}
