<?php

namespace Layerdrops\Solox\Widgets;


class Testimonials extends \Elementor\Widget_Base
{
    public function get_name()
    {
        return 'solox-testimonials';
    }

    public function get_title()
    {
        return __('Testimonials', 'solox-addon');
    }

    public function get_icon()
    {
        return 'eicon-cogs';
    }

    public function get_categories()
    {
        return ['solox-category'];
    }

    protected function register_controls()
    {


        $this->start_controls_section(
            'layout_section',
            [
                'label' => __('Layout', 'solox-addon'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'layout_type',
            [
                'label' => __('Select Layout', 'solox-addon'),
                'type' => \Elementor\Controls_Manager::SELECT2,
                'default' => 'layout_one',
                'options' => [
                    'layout_one' => __('Layout One', 'solox-addon'),
                    'layout_two' => __('Layout Two', 'solox-addon'),
                    'layout_three' => __('Layout Three', 'solox-addon'),
                    'layout_four' => __('Layout Four', 'solox-addon'),
                    'layout_five' => __('Layout Five', 'solox-addon'),
                    'layout_six' => __('Layout Six', 'solox-addon'),
                ]
            ]
        );

        $this->end_controls_section();

        include solox_get_elementor_option('testimonial-one-option.php');
        include solox_get_elementor_option('testimonial-three-option.php');
        include solox_get_elementor_option('testimonial-four-option.php');
        include solox_get_elementor_option('testimonial-five-option.php');
        include solox_get_elementor_option('testimonial-six-option.php');


        //General style
        $this->start_controls_section(
            'general_style',
            [
                'label' => esc_html__('Content Style', 'solox-addon'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        solox_elementor_general_style_options($this, 'Section Title', '{{WRAPPER}} .sec-title__title', ['layout_three', 'layout_five']);
        solox_elementor_general_style_options($this, 'Section Sub Title', '{{WRAPPER}} .sec-title__tagline', ['layout_three', 'layout_five']);
        solox_elementor_general_style_options($this, 'Section Summary', '{{WRAPPER}} .testimonials-one--home__text,{{WRAPPER}} .testimonials-three__content__text', ['layout_three', 'layout_five']);

        solox_elementor_general_style_options($this, 'Name', '{{WRAPPER}} .testimonials-card__name,{{WRAPPER}} .testimonials-two__item__quote,{{WRAPPER}} .testimonials-two__meta__name,{{WRAPPER}} .testimonials-three__meta__title', ['layout_one', 'layout_two', 'layout_three', 'layout_four', 'layout_five']);
        solox_elementor_general_style_options($this, 'Designation', '{{WRAPPER}} .testimonials-card__designation,{{WRAPPER}} .testimonials-two__meta__designation,{{WRAPPER}} .testimonials-three__meta__designation', ['layout_one', 'layout_two', 'layout_three', 'layout_four', 'layout_five']);
        solox_elementor_general_style_options($this, 'Testimonial', '{{WRAPPER}} .testimonials-card__content,{{WRAPPER}} .testimonials-two__item__quote,{{WRAPPER}} .testimonials-three__quote', ['layout_one', 'layout_two', 'layout_three', 'layout_four', 'layout_five']);

        $this->end_controls_section();

        solox_get_elementor_carousel_options($this, ['layout_one', 'layout_two', 'layout_three', 'layout_four', 'layout_five', 'layout_six']);
    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        include solox_get_template('testimonials-one.php');
        include solox_get_template('testimonials-two.php');
        include solox_get_template('testimonials-three.php');
        include solox_get_template('testimonials-four.php');
        include solox_get_template('testimonials-five.php');
        include solox_get_template('testimonials-six.php');
    }
}
